using System.Collections.Generic;
using UnityEngine;

// Responsible for opening/closing the upgradfe store as well as hiding other UI elements.
public class StoreStateHandler : MonoBehaviour, IRoundCallback
{

    [SerializeField] GameObject storeButton;
    [SerializeField] GameObject storeContainer;
    [SerializeField] List<GameObject> objectsToHideOnOpenStore;

    BaseCameraController cameraController;

    void Start()
    {
        cameraController = Camera.main.GetComponent<BaseCameraController>();
        RoundController.instance.roundCallbacks.Add(this);
    }

    public void OpenStore()
    {
        cameraController.SetUserControlEnabled(false);
        storeContainer.SetActive(true);
        storeButton.SetActive(false);
        objectsToHideOnOpenStore.ForEach(o => o.SetActive(false));
        DragDestroyController.instance.SetDraggingEnabled(false);
    }

    public void CloseStore()
    {
        cameraController.SetUserControlEnabled(true);
        storeContainer.SetActive(false);
        storeButton.SetActive(true);
        objectsToHideOnOpenStore.ForEach(o => o.SetActive(true));
        DragDestroyController.instance.SetDraggingEnabled(true);
    }

    public void OnRoundStart()
    {
        CloseStore();
        storeButton.SetActive(false);
    }

    public void OnRoundEnd(bool won)
    {
        storeButton.SetActive(true);
    }

}
