using System.Collections.Generic;
using UnityEngine;
using UnityEngine.UI;

// Powers the Shop. Allows you to purchase Upgrades. Displays how many of each
// Upgrade you already own and how much additional Upgrades cost.
public class StoreUpgradeController : MonoBehaviour
{

    [SerializeField] Button manaButton;
    [SerializeField] List<AudioClip> upgradeBuySfx;

    [Header("Price Texts")]
    [SerializeField] Text healthText;
    [SerializeField] Text damageText;
    [SerializeField] Text armorText;
    [SerializeField] Text manaText;

    [Header("Multiplier Texts")]
    [SerializeField] Text healthMultiplierText;
    [SerializeField] Text damageMultiplierText;
    [SerializeField] Text armorMultiplierText;
    [SerializeField] Text manaMultiplierText;

    Dictionary<UpgradeTypes, Text> upgradeTexts = new Dictionary<UpgradeTypes, Text>();
    Dictionary<UpgradeTypes, Text> multiplierTexts = new Dictionary<UpgradeTypes, Text>();
    BaseCameraController cameraController;


    private void Awake()
    {
        // Display initial values
        upgradeTexts.Add(UpgradeTypes.ENEMY_HEALTH, healthText);
        upgradeTexts.Add(UpgradeTypes.ENEMY_DAMAGE, damageText);
        upgradeTexts.Add(UpgradeTypes.ENEMY_ARMOR, armorText);
        upgradeTexts.Add(UpgradeTypes.MANA_COST, manaText);
        UpdateCostTexts();

        multiplierTexts.Add(UpgradeTypes.ENEMY_HEALTH, healthMultiplierText);
        multiplierTexts.Add(UpgradeTypes.ENEMY_DAMAGE, damageMultiplierText);
        multiplierTexts.Add(UpgradeTypes.ENEMY_ARMOR, armorMultiplierText);
        multiplierTexts.Add(UpgradeTypes.MANA_COST, manaMultiplierText);

        foreach (KeyValuePair<UpgradeTypes, Text> multiplierText in multiplierTexts)
        {
            multiplierText.Value.text = StatsManager.instance.GetTotalEffectMultiplier(multiplierText.Key).ToString("F2");
        }

        cameraController = Camera.main.GetComponent<BaseCameraController>();
    }

    // Called whenever a button to buy an Upgrade is called.
    public void Buy(string upgradeType)
    {
        switch (upgradeType)
        {
            case "Health":
                BuyUpgrade(UpgradeTypes.ENEMY_HEALTH);
                break;
            case "Damage":
                BuyUpgrade(UpgradeTypes.ENEMY_DAMAGE);
                break;
            case "Armor":
                BuyUpgrade(UpgradeTypes.ENEMY_ARMOR);
                break;
            case "Mana":
                BuyUpgrade(UpgradeTypes.MANA_COST);
                break;
        }
    }

    void BuyUpgrade(UpgradeTypes upgradeType)
    {
        if (StatsManager.instance.BuyUpgrade(upgradeType))
        {
            upgradeTexts[upgradeType].text = StatsManager.instance.GetNextUpgradeCost(upgradeType).ToString();
            multiplierTexts[upgradeType].text = StatsManager.instance.GetTotalEffectMultiplier(upgradeType).ToString("F2");
            if (upgradeType == UpgradeTypes.MANA_COST)
            {
                UpdateCostTexts();
                MaybeDeactivateBuyManaButton();
            }
            cameraController.PlayRandomGlobalAudioClip(upgradeBuySfx);
        }

    }

    void UpdateCostTexts()
    {
        foreach (KeyValuePair<UpgradeTypes, Text> upgradeText in upgradeTexts)
        {
            upgradeText.Value.text = StatsManager.instance.GetNextUpgradeCost(upgradeText.Key).ToString();
        }
    }

    // Don't allow you to buy enough Mana Cost Decrease Upgrades to be able to spend negative Mana, aka gain Mana with purchases
    void MaybeDeactivateBuyManaButton()
    {
        if (StatsManager.instance.GetTotalEffectMultiplier(UpgradeTypes.MANA_COST) <= 0.1)
        {
            manaButton.interactable = false;
            multiplierTexts[UpgradeTypes.MANA_COST].text = "0.1";
            upgradeTexts[UpgradeTypes.MANA_COST].text = "";
        }
    }
}
