using UnityEngine;

// A Canvas for displaying how much damage was dealt to an enemy.
// Can also show any kind of other text.
public class DamageIndicatorCanvas : MonoBehaviour
{

    [SerializeField] GameObject indicatorTextPrefab;

    RectTransform rectTransform;
    Vector3 initialScale;

    void Awake()
    {
        rectTransform = GetComponent<RectTransform>();
        var canvas = GetComponent<Canvas>();
        canvas.worldCamera = Camera.main;
        initialScale = transform.localScale;
    }

    private void Update()
    {
        // Always face the correct orientation, even when the parent Fighter is flipped.
        // If transform.parent.localScale.x is -1, the canvas scale will be set to -1
        // as well, effectively cancelling the flip.
        var scale = transform.localScale;
        scale.x = transform.parent.localScale.x < 0 ? -initialScale.x : initialScale.x;
        transform.localScale = scale;
    }

    // Creates a new, short-lived text element displaying the given text.
    public void FlashText(string text, bool center = false)
    {
        var rect = rectTransform.rect;
        var pos = transform.position + (center ? (Vector3)rect.center : new Vector3(Random.Range(rect.xMin, rect.xMax), Random.Range(rect.yMin, rect.yMax)));
        Instantiate(indicatorTextPrefab, pos, Quaternion.identity, transform).GetComponent<DamageIndicatorText>().text = text;
    }
}
