using UnityEngine;

// It's a health bar. You know what it does.
public class HealthBarController : MonoBehaviour
{

    [SerializeField] Color barColor = new Color(245, 17, 17);

    Transform bar;
    Vector3 initialScale;

    void Awake()
    {
        bar = transform.Find("Bar");
        bar.Find("Health").GetComponent<SpriteRenderer>().color = barColor;
        initialScale = transform.localScale;
    }

    private void Update()
    {
        // Always face the correct orientation, even when the parent Fighter is flipped.
        // If transform.parent.localScale.x is -1, the health bar scale will be set to -1
        // as well, effectively cancelling the flip.
        var scale = transform.localScale;
        scale.x = transform.parent.localScale.x < 0 ? -initialScale.x : initialScale.x;
        transform.localScale = scale;
    }

    // Has to be a value between 0 and 1
    public void ShowHealth(float health)
    {
        Vector3 scaleValue = bar.transform.localScale;
        scaleValue.x = health;
        bar.transform.localScale = scaleValue;
    }

    public void SetHealthBarEnabled(bool enabled)
    {
        gameObject.SetActive(enabled);
    }

    public void Reset()
    {
        SetHealthBarEnabled(true);
        ShowHealth(1f);
    }
}
